==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/subsystem/impl/BaseAttributeSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.subsystem.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.subsystem.BaseAttribute;
import io.ciera.tool.sql.ooaofooa.subsystem.BaseAttributeSet;
import io.ciera.tool.sql.ooaofooa.subsystem.DerivedBaseAttributeSet;
import io.ciera.tool.sql.ooaofooa.subsystem.NewBaseAttributeSet;
import io.ciera.tool.sql.ooaofooa.subsystem.O_ATTRSet;
import io.ciera.tool.sql.ooaofooa.subsystem.ReferentialAttributeSet;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.DerivedBaseAttributeSetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.NewBaseAttributeSetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.O_ATTRSetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.ReferentialAttributeSetImpl;

import java.util.Arrays;
import java.util.List;


public class BaseAttributeSetImpl extends InstanceSet<BaseAttributeSet,BaseAttribute> implements BaseAttributeSet {

    // attributes
    @Override
    public void setObj_ID( UniqueId ref_Obj_ID ) throws XtumlException {
        for ( BaseAttribute baseattribute : this ) baseattribute.setObj_ID( ref_Obj_ID );
    }
    @Override
    public void setAttr_ID( UniqueId ref_Attr_ID ) throws XtumlException {
        for ( BaseAttribute baseattribute : this ) baseattribute.setAttr_ID( ref_Attr_ID );
    }


    // selections
    @Override
    public O_ATTRSet R106_is_a_O_ATTR() throws XtumlException {
        O_ATTRSet o_attrset = new O_ATTRSetImpl();
        for ( BaseAttribute baseattribute : this ) o_attrset.add( baseattribute.R106_is_a_O_ATTR() );
        return o_attrset;
    }
    @Override
    public DerivedBaseAttributeSet R107_is_a_DerivedBaseAttribute() throws XtumlException {
        DerivedBaseAttributeSet derivedbaseattributeset = new DerivedBaseAttributeSetImpl();
        for ( BaseAttribute baseattribute : this ) derivedbaseattributeset.add( baseattribute.R107_is_a_DerivedBaseAttribute() );
        return derivedbaseattributeset;
    }
    @Override
    public NewBaseAttributeSet R107_is_a_NewBaseAttribute() throws XtumlException {
        NewBaseAttributeSet newbaseattributeset = new NewBaseAttributeSetImpl();
        for ( BaseAttribute baseattribute : this ) newbaseattributeset.add( baseattribute.R107_is_a_NewBaseAttribute() );
        return newbaseattributeset;
    }
    @Override
    public ReferentialAttributeSet R113_can_be_the_base_of_ReferentialAttribute() throws XtumlException {
        ReferentialAttributeSet referentialattributeset = new ReferentialAttributeSetImpl();
        for ( BaseAttribute baseattribute : this ) referentialattributeset.addAll( baseattribute.R113_can_be_the_base_of_ReferentialAttribute() );
        return referentialattributeset;
    }


    @Override
    public BaseAttribute nullElement() {
        return BaseAttributeImpl.EMPTY_BASEATTRIBUTE;
    }

    @Override
    public BaseAttributeSet emptySet() {
      return new BaseAttributeSetImpl();
    }

    @Override
    public BaseAttributeSet value() {
        return this;
    }

    @Override
    public List<BaseAttribute> elements() {
        return Arrays.asList(toArray(new BaseAttribute[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/subsystem/impl/BaseAttributeSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.subsystem.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.subsystem.BaseAttribute;
import io.ciera.tool.sql.ooaofooa.subsystem.BaseAttributeSet;
import io.ciera.tool.sql.ooaofooa.subsystem.DerivedBaseAttributeSet;
import io.ciera.tool.sql.ooaofooa.subsystem.NewBaseAttributeSet;
import io.ciera.tool.sql.ooaofooa.subsystem.O_ATTRSet;
import io.ciera.tool.sql.ooaofooa.subsystem.ReferentialAttributeSet;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.DerivedBaseAttributeSetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.NewBaseAttributeSetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.O_ATTRSetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.ReferentialAttributeSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class BaseAttributeSetImpl extends InstanceSet<BaseAttributeSet,BaseAttribute> implements BaseAttributeSet {

    public BaseAttributeSetImpl() {
    }

    public BaseAttributeSetImpl(Comparator<? super BaseAttribute> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setAttr_ID( UniqueId ref_Attr_ID ) throws XtumlException {
        for ( BaseAttribute baseattribute : this ) baseattribute.setAttr_ID( ref_Attr_ID );
    }
    @Override
    public void setObj_ID( UniqueId ref_Obj_ID ) throws XtumlException {
        for ( BaseAttribute baseattribute : this ) baseattribute.setObj_ID( ref_Obj_ID );
    }


    // selections
    @Override
    public O_ATTRSet R106_is_a_O_ATTR() throws XtumlException {
        O_ATTRSet o_attrset = new O_ATTRSetImpl();
        for ( BaseAttribute baseattribute : this ) o_attrset.add( baseattribute.R106_is_a_O_ATTR() );
        return o_attrset;
    }
    @Override
    public DerivedBaseAttributeSet R107_is_a_DerivedBaseAttribute() throws XtumlException {
        DerivedBaseAttributeSet derivedbaseattributeset = new DerivedBaseAttributeSetImpl();
        for ( BaseAttribute baseattribute : this ) derivedbaseattributeset.add( baseattribute.R107_is_a_DerivedBaseAttribute() );
        return derivedbaseattributeset;
    }
    @Override
    public NewBaseAttributeSet R107_is_a_NewBaseAttribute() throws XtumlException {
        NewBaseAttributeSet newbaseattributeset = new NewBaseAttributeSetImpl();
        for ( BaseAttribute baseattribute : this ) newbaseattributeset.add( baseattribute.R107_is_a_NewBaseAttribute() );
        return newbaseattributeset;
    }
    @Override
    public ReferentialAttributeSet R113_can_be_the_base_of_ReferentialAttribute() throws XtumlException {
        ReferentialAttributeSet referentialattributeset = new ReferentialAttributeSetImpl();
        for ( BaseAttribute baseattribute : this ) referentialattributeset.addAll( baseattribute.R113_can_be_the_base_of_ReferentialAttribute() );
        return referentialattributeset;
    }


    @Override
    public BaseAttribute nullElement() {
        return BaseAttributeImpl.EMPTY_BASEATTRIBUTE;
    }

    @Override
    public BaseAttributeSet emptySet() {
      return new BaseAttributeSetImpl();
    }

    @Override
    public BaseAttributeSet emptySet(Comparator<? super BaseAttribute> comp) {
      return new BaseAttributeSetImpl(comp);
    }

    @Override
    public BaseAttributeSet value() {
        return this;
    }

    @Override
    public List<BaseAttribute> elements() {
        return Arrays.asList(toArray(new BaseAttribute[0]));
    }

}
